@@ -11,7 +11,7 @@ Business::Fixflo - Perl library for interacting with the Fixflo API
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 DESCRIPTION
 
@@ -89,6 +89,12 @@ appropriate error catching code (TryCatch in the below example):
         ...
     }
 
+You can view some useful debugging information by setting the FIXFLO_DEBUG
+env varible, this will show the calls to the Fixflo endpoints as well as a
+stack trace in the event of exceptions:
+
+    $ENV{FIXFLO_DEBUG} = 1;
+
 =cut
 
 use Moo;
